@@ -14,7 +14,7 @@ from marshmallow import ValidationError
 from .deserializers import JSONDeserializer
 from .errors import create_errormap_handler
 from .loaders import RequestLoader
-from .parsers import ArgsParser
+from .parsers import HeadersParser, URLArgsParser
 from .responses import Response
 from .serializers import JSONSerializer
 from .views import ItemView, ListView, SingletonView
@@ -32,7 +32,8 @@ class ResourceConfig:
     response_handlers = {"application/json": Response(JSONSerializer())}
     item_route = "/resources/<id>"
     list_route = "/resources/"
-    request_url_args_parser = ArgsParser()
+    request_url_args_parser = URLArgsParser()
+    request_headers_parser = HeadersParser()
     default_content_type = "application/json"
     default_accept_mimetype = "application/json"
 
@@ -49,27 +50,27 @@ class Resource:
         self.bp_name = None
 
     # Primary interface
-    def search(self, *args, **kwargs):
+    def search(self):
         """Perform a search over the items."""
         return [], 200
 
-    def create(self, *args, **kwargs):
+    def create(self):
         """Create an item."""
         return {}, 200
 
-    def read(self, *args, **kwargs):
+    def read(self):
         """Read an item."""
         return {}, 200
 
-    def update(self, *args, **kwargs):
+    def update(self):
         """Update an item."""
         return {}, 200
 
-    def partial_update(self, *args, **kwargs):
+    def partial_update(self):
         """Partial update an item."""
         return {}, 200
 
-    def delete(self, *args, **kwargs):
+    def delete(self):
         """Delete an item."""
         return {}, 200
 
@@ -93,7 +94,8 @@ class Resource:
             {
                 "rule": self.config.item_route,
                 "view_func": ItemView.as_view(
-                    name="{}".format(bp_name), resource=self,
+                    name=f"{bp_name}",
+                    resource=self,
                 ),
             }
         ]
@@ -107,11 +109,11 @@ class Resource:
 class CollectionResource(Resource):
     """CollectionResource."""
 
-    def update_all(self, *args, **kwargs):
+    def update_all(self):
         """Delete an item."""
         return [], 200
 
-    def delete_all(self, *args, **kwargs):
+    def delete_all(self):
         """Delete an item."""
         return [], 200
 
@@ -121,13 +123,15 @@ class CollectionResource(Resource):
             {
                 "rule": self.config.item_route,
                 "view_func": ItemView.as_view(
-                    name="{}{}".format(bp_name, ITEM_VIEW_SUFFIX), resource=self,
+                    name=f"{bp_name}{ITEM_VIEW_SUFFIX}",
+                    resource=self,
                 ),
             },
             {
                 "rule": self.config.list_route,
                 "view_func": ListView.as_view(
-                    name="{}{}".format(bp_name, LIST_VIEW_SUFFIX), resource=self,
+                    name=f"{bp_name}{LIST_VIEW_SUFFIX}",
+                    resource=self,
                 ),
             },
         ]
@@ -142,7 +146,8 @@ class SingletonResource(Resource):
             {
                 "rule": self.config.list_route,
                 "view_func": SingletonView.as_view(
-                    name="{}".format(bp_name), resource=self,
+                    name=f"{bp_name}",
+                    resource=self,
                 ),
             }
         ]
